Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: tools/perf/benchmarks/blob_storage.py

Issue 1104053006: [Storage] Blob Storage perf tests (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Whoops, forgot timeline metric Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tools/perf/page_sets/blob/blob-workshop.html » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/perf/benchmarks/blob_storage.py
diff --git a/tools/perf/benchmarks/new_tab.py b/tools/perf/benchmarks/blob_storage.py
similarity index 50%
copy from tools/perf/benchmarks/new_tab.py
copy to tools/perf/benchmarks/blob_storage.py
index 961f0e73b9e8d8ff6cb6bc478a84da2011cb41de..a12070d87fa3c278a74d28083dafc591610655c9 100644
--- a/tools/perf/benchmarks/new_tab.py
+++ b/tools/perf/benchmarks/blob_storage.py
@@ -2,23 +2,23 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
from telemetry import benchmark
+from telemetry.core.platform import tracing_category_filter
from telemetry.web_perf import timeline_based_measurement
import page_sets
+TOPLEVEL_CATEGORY = 'Blob'
-@benchmark.Disabled('android')
-class NewTabPage(benchmark.Benchmark):
- """Timeline based measurement benchmark for the New Tab Page."""
- page_set = page_sets.NewTabPagePageSet
+class BlobStorage(benchmark.Benchmark):
+ """Timeline based measurement benchmark for Blob Storage."""
+ page_set = page_sets.BlobWorkshopPageSet
def CreateTimelineBasedMeasurementOptions(self):
+ cat_filter = tracing_category_filter.TracingCategoryFilter(
+ TOPLEVEL_CATEGORY)
nednguyen 2015/05/07 10:51:05 My guess is this category filter confused telemetr
return timeline_based_measurement.Options(
- overhead_level=timeline_based_measurement.MINIMAL_OVERHEAD_LEVEL)
+ overhead_level=cat_filter)
@classmethod
def Name(cls):
- return 'new_tab.new_tab_page'
-
- # TODO(beaudoin): Define ValueCanBeAddedPredicate to filter out things we
- # don't care for.
+ return 'blob_storage.blob_storage'
« no previous file with comments | « no previous file | tools/perf/page_sets/blob/blob-workshop.html » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698